RemotePathDataLoader — PyRemoteData 0.0.48 documentation

Skip to content

# RemotePathDataLoader

class pyremotedata.dataloader.RemotePathDataLoader(dataset: RemotePathDataset, num_workers: int = 0, shuffle: bool = False, *args, **kwargs)

  Bases: `DataLoader`

  A custom `torch.utils.data.DataLoader` for `pyremotedata.dataloader.RemotePathDataset`.

  This DataLoader is designed to work with `pyremotedata.dataloader.RemotePathDataset` and does not support all the arguments of the standard `torch.utils.data.DataLoader`.

  Unsupported arguments: - sampler - batch_sampler

  Parameters:

    - dataset (RemotePathDataset) – The `pyremotedata.dataloader.RemotePathDataset` dataset to load from.

    - num_workers (int, optional) – The number of worker threads to use for loading. Default: 0. Must be greater than 0.

    - shuffle (bool, optional) – Whether to shuffle the dataset between epochs. Default: False.